defmodule PhoenixPasskeys.Application do
  # See https://hexdocs.pm/elixir/Application.html
  # for more information on OTP Applications
  @moduledoc false

  use Application

  @impl true
  def start(_type, _args) do
    children = [
      # Start the Telemetry supervisor
      PhoenixPasskeysWeb.Telemetry,
      # Start the Ecto repository
      PhoenixPasskeys.Repo,
      # Start the PubSub system
      {Phoenix.PubSub, name: PhoenixPasskeys.PubSub},
      # Start Finch
      {Finch, name: PhoenixPasskeys.Finch},
      # Start the Endpoint (http/https)
      PhoenixPasskeysWeb.Endpoint
      # Start a worker by calling: PhoenixPasskeys.Worker.start_link(arg)
      # {PhoenixPasskeys.Worker, arg}
    ]

    # See https://hexdocs.pm/elixir/Supervisor.html
    # for other strategies and supported options
    opts = [strategy: :one_for_one, name: PhoenixPasskeys.Supervisor]
    Supervisor.start_link(children, opts)
  end

  # Tell Phoenix to update the endpoint configuration
  # whenever the application is updated.
  @impl true
  def config_change(changed, _new, removed) do
    PhoenixPasskeysWeb.Endpoint.config_change(changed, removed)
    :ok
  end
end
